use v6.c;
class LoadFromInsideAClass {
    use Foo;
}
